==> hs-Agda-2.2.6.tbz: lib/Agda-2.2.6/register.sh <==
#!/bin/sh

echo 'name: Agda
version: 2.2.6
license: OtherLicense
copyright:
maintainer: Ulf Norell <ulfn@chalmers.se>
stability:
homepage: http://wiki.portal.chalmers.se/agda/
package-url:
description: Agda is a dependently typed functional programming language: It has
             inductive families, which are similar to Haskell'\''s GADTs, but they
             can be indexed by values and not just types. It also has
             parameterised modules, mixfix operators, Unicode characters, and an
             interactive Emacs interface (the type checker can assist in the
             development of your code).
             .
             Agda is also a proof assistant: It is an interactive system for
             writing and checking proofs. Agda is based on intuitionistic type
             theory, a foundational system for constructive mathematics developed
             by the Swedish logician Per Martin-L&#xf6;f. It has many
             similarities with other proof assistants based on dependent types,
             such as Coq, Epigram and NuPRL.
             .
             Note that if you want to use the command-line program (agda), then
             you should also install the Agda-executable package. The Agda
             package includes an Emacs mode for Agda, but you need to set up the
             Emacs mode yourself (for instance by running @agda-mode setup@; see
             the README).
             .
             Note also that this library does not follow the package versioning
             policy, because the library is only intended to be used by the Emacs
             mode and the Agda-executable package.
category: Dependent types
author: Ulf Norell, Nils Anders Danielsson, Catarina Coquand, Makoto Takeyama, Andreas Abel, ...
exposed: True
exposed-modules: Agda.Main Agda.Interaction.BasicOps
                 Agda.Interaction.GhciTop Agda.Compiler.Agate.Classify
                 Agda.Compiler.Agate.Common Agda.Compiler.Agate.Main
                 Agda.Compiler.Agate.OptimizedPrinter
                 Agda.Compiler.Agate.TranslateName
                 Agda.Compiler.Agate.UntypedPrinter Agda.Compiler.Alonzo.Main
                 Agda.Compiler.Alonzo.Names Agda.Compiler.Alonzo.Haskell
                 Agda.Compiler.Alonzo.PatternMonad Agda.Compiler.HaskellTypes
                 Agda.Compiler.MAlonzo.Compiler Agda.Compiler.MAlonzo.Encode
                 Agda.Compiler.MAlonzo.Misc Agda.Compiler.MAlonzo.Pretty
                 Agda.Compiler.MAlonzo.Primitives
                 Agda.Interaction.CommandLine.CommandLine
                 Agda.Interaction.Exceptions Agda.Interaction.FindFile
                 Agda.Interaction.Highlighting.Emacs
                 Agda.Interaction.Highlighting.Generate
                 Agda.Interaction.Highlighting.HTML
                 Agda.Interaction.Highlighting.Precise
                 Agda.Interaction.Highlighting.Range
                 Agda.Interaction.Highlighting.Vim Agda.Interaction.Imports
                 Agda.Interaction.MakeCase Agda.Interaction.Monad
                 Agda.Interaction.Options Agda.Syntax.Abstract.Name
                 Agda.Syntax.Abstract.Pretty Agda.Syntax.Abstract.Views
                 Agda.Syntax.Abstract Agda.Syntax.Common
                 Agda.Syntax.Concrete.Definitions Agda.Syntax.Concrete.Name
                 Agda.Syntax.Concrete.Operators.Parser
                 Agda.Syntax.Concrete.Operators Agda.Syntax.Concrete.Pretty
                 Agda.Syntax.Concrete Agda.Syntax.Fixity Agda.Syntax.Info
                 Agda.Syntax.Internal Agda.Syntax.Internal.Generic
                 Agda.Syntax.Internal.Pattern Agda.Syntax.Literal
                 Agda.Syntax.Parser.Alex Agda.Syntax.Parser.Comments
                 Agda.Syntax.Parser.Layout Agda.Syntax.Parser.LexActions
                 Agda.Syntax.Parser.Lexer Agda.Syntax.Parser.LookAhead
                 Agda.Syntax.Parser.Monad Agda.Syntax.Parser.Parser
                 Agda.Syntax.Parser.StringLiterals Agda.Syntax.Parser.Tokens
                 Agda.Syntax.Parser Agda.Syntax.Position Agda.Syntax.Scope.Base
                 Agda.Syntax.Scope.Monad Agda.Syntax.Strict
                 Agda.Syntax.Translation.AbstractToConcrete
                 Agda.Syntax.Translation.ConcreteToAbstract
                 Agda.Syntax.Translation.InternalToAbstract
                 Agda.Termination.CallGraph Agda.Termination.Lexicographic
                 Agda.Termination.Matrix Agda.Termination.Semiring
                 Agda.Termination.TermCheck Agda.Termination.Termination Agda.Tests
                 Agda.TypeChecker Agda.TypeChecking.Abstract
                 Agda.TypeChecking.Constraints Agda.TypeChecking.Conversion
                 Agda.TypeChecking.Coverage Agda.TypeChecking.Coverage.Match
                 Agda.TypeChecking.DisplayForm Agda.TypeChecking.Empty
                 Agda.TypeChecking.EtaContract Agda.TypeChecking.Errors
                 Agda.TypeChecking.Free Agda.TypeChecking.Implicit
                 Agda.TypeChecking.Injectivity Agda.TypeChecking.Level
                 Agda.TypeChecking.MetaVars Agda.TypeChecking.MetaVars.Occurs
                 Agda.TypeChecking.Monad.Base Agda.TypeChecking.Monad.Builtin
                 Agda.TypeChecking.Monad.Closure Agda.TypeChecking.Monad.Constraints
                 Agda.TypeChecking.Monad.Context Agda.TypeChecking.Monad.Debug
                 Agda.TypeChecking.Monad.Env Agda.TypeChecking.Monad.Exception
                 Agda.TypeChecking.Monad.Imports Agda.TypeChecking.Monad.MetaVars
                 Agda.TypeChecking.Monad.Mutual Agda.TypeChecking.Monad.Open
                 Agda.TypeChecking.Monad.Options Agda.TypeChecking.Monad.Signature
                 Agda.TypeChecking.Monad.SizedTypes Agda.TypeChecking.Monad.State
                 Agda.TypeChecking.Monad.Statistics Agda.TypeChecking.Monad.Trace
                 Agda.TypeChecking.Monad Agda.TypeChecking.Patterns.Match
                 Agda.TypeChecking.Polarity Agda.TypeChecking.Positivity
                 Agda.TypeChecking.Pretty Agda.TypeChecking.Primitive
                 Agda.TypeChecking.Rebind Agda.TypeChecking.Records
                 Agda.TypeChecking.Reduce Agda.TypeChecking.Rules.Builtin
                 Agda.TypeChecking.Rules.Data Agda.TypeChecking.Rules.Decl
                 Agda.TypeChecking.Rules.Def Agda.TypeChecking.Rules.LHS
                 Agda.TypeChecking.Rules.LHS.Implicit
                 Agda.TypeChecking.Rules.LHS.Instantiate
                 Agda.TypeChecking.Rules.LHS.Problem
                 Agda.TypeChecking.Rules.LHS.Split Agda.TypeChecking.Rules.LHS.Unify
                 Agda.TypeChecking.Rules.Record Agda.TypeChecking.Rules.Term
                 Agda.TypeChecking.Serialise Agda.TypeChecking.SizedTypes
                 Agda.TypeChecking.Substitute Agda.TypeChecking.Telescope
                 Agda.TypeChecking.Test.Generators Agda.TypeChecking.Tests
                 Agda.TypeChecking.With Agda.Utils.Char Agda.Utils.Either
                 Agda.Utils.FileName Agda.Utils.Fresh Agda.Utils.Function
                 Agda.Utils.Generics Agda.Utils.Graph Agda.Utils.Hash
                 Agda.Utils.Impossible Agda.Utils.IO.Binary Agda.Utils.IO.Locale
                 Agda.Utils.IO.UTF8 Agda.Utils.List Agda.Utils.Map Agda.Utils.Maybe
                 Agda.Utils.Monad Agda.Utils.Permutation Agda.Utils.Pointer
                 Agda.Utils.Pretty Agda.Utils.QuickCheck Agda.Utils.ReadP
                 Agda.Utils.SemiRing Agda.Utils.Size Agda.Utils.String
                 Agda.Utils.Suffix Agda.Utils.TestHelpers Agda.Utils.Trace
                 Agda.Utils.Trie Agda.Utils.Tuple Agda.Utils.Unicode
                 Agda.Utils.Warshall Agda.Version Agda.Auto.Auto Agda.Auto.Convert
                 Agda.Auto.Typecheck Agda.Auto.NarrowingSearch Agda.Auto.Print
                 Agda.Auto.Syntax Agda.Auto.SearchControl
hidden-modules: Paths_Agda
import-dirs: /usr/local/lib/Agda-2.2.6/ghc-6.10.4
library-dirs: /usr/local/lib/Agda-2.2.6/ghc-6.10.4
hs-libraries: HSAgda-2.2.6
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: QuickCheck-2.1.0.2 array-0.2.0.0 base-4.1.0.0
         binary-0.5.0.2 bytestring-0.9.1.4 containers-0.2.0.1
         directory-1.0.0.3 filepath-1.1.0.2 haskeline-0.6.2.2
         haskell-src-1.0.1.3 mtl-1.1.0.2 old-time-1.0.0.2 pretty-1.0.1.0
         process-1.0.1.1 syb-0.1.0.1 utf8-string-0.3.6 xhtml-3000.2.0.1
         zlib-0.5.2.0
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/Agda-2.2.6/html/Agda.haddock
haddock-html: /usr/local/share/doc/Agda-2.2.6/html' | /usr/local/bin/ghc-pkg update -

==> hs-Agda-2.2.6_1.tbz: lib/Agda-2.2.6/register.sh <==
#!/bin/sh

echo 'name: Agda
version: 2.2.6
license: OtherLicense
copyright:
maintainer: Ulf Norell <ulfn@chalmers.se>
stability:
homepage: http://wiki.portal.chalmers.se/agda/
package-url:
description: Agda is a dependently typed functional programming language: It has
             inductive families, which are similar to Haskell'\''s GADTs, but they
             can be indexed by values and not just types. It also has
             parameterised modules, mixfix operators, Unicode characters, and an
             interactive Emacs interface (the type checker can assist in the
             development of your code).
             .
             Agda is also a proof assistant: It is an interactive system for
             writing and checking proofs. Agda is based on intuitionistic type
             theory, a foundational system for constructive mathematics developed
             by the Swedish logician Per Martin-L&#xf6;f. It has many
             similarities with other proof assistants based on dependent types,
             such as Coq, Epigram and NuPRL.
             .
             Note that if you want to use the command-line program (agda), then
             you should also install the Agda-executable package. The Agda
             package includes an Emacs mode for Agda, but you need to set up the
             Emacs mode yourself (for instance by running @agda-mode setup@; see
             the README).
             .
             Note also that this library does not follow the package versioning
             policy, because the library is only intended to be used by the Emacs
             mode and the Agda-executable package.
category: Dependent types
author: Ulf Norell, Nils Anders Danielsson, Catarina Coquand, Makoto Takeyama, Andreas Abel, ...
exposed: True
exposed-modules: Agda.Main Agda.Interaction.BasicOps
                 Agda.Interaction.GhciTop Agda.Compiler.Agate.Classify
                 Agda.Compiler.Agate.Common Agda.Compiler.Agate.Main
                 Agda.Compiler.Agate.OptimizedPrinter
                 Agda.Compiler.Agate.TranslateName
                 Agda.Compiler.Agate.UntypedPrinter Agda.Compiler.Alonzo.Main
                 Agda.Compiler.Alonzo.Names Agda.Compiler.Alonzo.Haskell
                 Agda.Compiler.Alonzo.PatternMonad Agda.Compiler.HaskellTypes
                 Agda.Compiler.MAlonzo.Compiler Agda.Compiler.MAlonzo.Encode
                 Agda.Compiler.MAlonzo.Misc Agda.Compiler.MAlonzo.Pretty
                 Agda.Compiler.MAlonzo.Primitives
                 Agda.Interaction.CommandLine.CommandLine
                 Agda.Interaction.Exceptions Agda.Interaction.FindFile
                 Agda.Interaction.Highlighting.Emacs
                 Agda.Interaction.Highlighting.Generate
                 Agda.Interaction.Highlighting.HTML
                 Agda.Interaction.Highlighting.Precise
                 Agda.Interaction.Highlighting.Range
                 Agda.Interaction.Highlighting.Vim Agda.Interaction.Imports
                 Agda.Interaction.MakeCase Agda.Interaction.Monad
                 Agda.Interaction.Options Agda.Syntax.Abstract.Name
                 Agda.Syntax.Abstract.Pretty Agda.Syntax.Abstract.Views
                 Agda.Syntax.Abstract Agda.Syntax.Common
                 Agda.Syntax.Concrete.Definitions Agda.Syntax.Concrete.Name
                 Agda.Syntax.Concrete.Operators.Parser
                 Agda.Syntax.Concrete.Operators Agda.Syntax.Concrete.Pretty
                 Agda.Syntax.Concrete Agda.Syntax.Fixity Agda.Syntax.Info
                 Agda.Syntax.Internal Agda.Syntax.Internal.Generic
                 Agda.Syntax.Internal.Pattern Agda.Syntax.Literal
                 Agda.Syntax.Parser.Alex Agda.Syntax.Parser.Comments
                 Agda.Syntax.Parser.Layout Agda.Syntax.Parser.LexActions
                 Agda.Syntax.Parser.Lexer Agda.Syntax.Parser.LookAhead
                 Agda.Syntax.Parser.Monad Agda.Syntax.Parser.Parser
                 Agda.Syntax.Parser.StringLiterals Agda.Syntax.Parser.Tokens
                 Agda.Syntax.Parser Agda.Syntax.Position Agda.Syntax.Scope.Base
                 Agda.Syntax.Scope.Monad Agda.Syntax.Strict
                 Agda.Syntax.Translation.AbstractToConcrete
                 Agda.Syntax.Translation.ConcreteToAbstract
                 Agda.Syntax.Translation.InternalToAbstract
                 Agda.Termination.CallGraph Agda.Termination.Lexicographic
                 Agda.Termination.Matrix Agda.Termination.Semiring
                 Agda.Termination.TermCheck Agda.Termination.Termination Agda.Tests
                 Agda.TypeChecker Agda.TypeChecking.Abstract
                 Agda.TypeChecking.Constraints Agda.TypeChecking.Conversion
                 Agda.TypeChecking.Coverage Agda.TypeChecking.Coverage.Match
                 Agda.TypeChecking.DisplayForm Agda.TypeChecking.Empty
                 Agda.TypeChecking.EtaContract Agda.TypeChecking.Errors
                 Agda.TypeChecking.Free Agda.TypeChecking.Implicit
                 Agda.TypeChecking.Injectivity Agda.TypeChecking.Level
                 Agda.TypeChecking.MetaVars Agda.TypeChecking.MetaVars.Occurs
                 Agda.TypeChecking.Monad.Base Agda.TypeChecking.Monad.Builtin
                 Agda.TypeChecking.Monad.Closure Agda.TypeChecking.Monad.Constraints
                 Agda.TypeChecking.Monad.Context Agda.TypeChecking.Monad.Debug
                 Agda.TypeChecking.Monad.Env Agda.TypeChecking.Monad.Exception
                 Agda.TypeChecking.Monad.Imports Agda.TypeChecking.Monad.MetaVars
                 Agda.TypeChecking.Monad.Mutual Agda.TypeChecking.Monad.Open
                 Agda.TypeChecking.Monad.Options Agda.TypeChecking.Monad.Signature
                 Agda.TypeChecking.Monad.SizedTypes Agda.TypeChecking.Monad.State
                 Agda.TypeChecking.Monad.Statistics Agda.TypeChecking.Monad.Trace
                 Agda.TypeChecking.Monad Agda.TypeChecking.Patterns.Match
                 Agda.TypeChecking.Polarity Agda.TypeChecking.Positivity
                 Agda.TypeChecking.Pretty Agda.TypeChecking.Primitive
                 Agda.TypeChecking.Rebind Agda.TypeChecking.Records
                 Agda.TypeChecking.Reduce Agda.TypeChecking.Rules.Builtin
                 Agda.TypeChecking.Rules.Data Agda.TypeChecking.Rules.Decl
                 Agda.TypeChecking.Rules.Def Agda.TypeChecking.Rules.LHS
                 Agda.TypeChecking.Rules.LHS.Implicit
                 Agda.TypeChecking.Rules.LHS.Instantiate
                 Agda.TypeChecking.Rules.LHS.Problem
                 Agda.TypeChecking.Rules.LHS.Split Agda.TypeChecking.Rules.LHS.Unify
                 Agda.TypeChecking.Rules.Record Agda.TypeChecking.Rules.Term
                 Agda.TypeChecking.Serialise Agda.TypeChecking.SizedTypes
                 Agda.TypeChecking.Substitute Agda.TypeChecking.Telescope
                 Agda.TypeChecking.Test.Generators Agda.TypeChecking.Tests
                 Agda.TypeChecking.With Agda.Utils.Char Agda.Utils.Either
                 Agda.Utils.FileName Agda.Utils.Fresh Agda.Utils.Function
                 Agda.Utils.Generics Agda.Utils.Graph Agda.Utils.Hash
                 Agda.Utils.Impossible Agda.Utils.IO.Binary Agda.Utils.IO.Locale
                 Agda.Utils.IO.UTF8 Agda.Utils.List Agda.Utils.Map Agda.Utils.Maybe
                 Agda.Utils.Monad Agda.Utils.Permutation Agda.Utils.Pointer
                 Agda.Utils.Pretty Agda.Utils.QuickCheck Agda.Utils.ReadP
                 Agda.Utils.SemiRing Agda.Utils.Size Agda.Utils.String
                 Agda.Utils.Suffix Agda.Utils.TestHelpers Agda.Utils.Trace
                 Agda.Utils.Trie Agda.Utils.Tuple Agda.Utils.Unicode
                 Agda.Utils.Warshall Agda.Version Agda.Auto.Auto Agda.Auto.Convert
                 Agda.Auto.Typecheck Agda.Auto.NarrowingSearch Agda.Auto.Print
                 Agda.Auto.Syntax Agda.Auto.SearchControl
hidden-modules: Paths_Agda
import-dirs: /usr/local/lib/Agda-2.2.6/ghc-6.10.4
library-dirs: /usr/local/lib/Agda-2.2.6/ghc-6.10.4 /usr/local/lib
hs-libraries: HSAgda-2.2.6
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: QuickCheck-2.1.0.3 array-0.2.0.0 base-4.1.0.0
         binary-0.5.0.2 bytestring-0.9.1.4 containers-0.2.0.1
         directory-1.0.0.3 filepath-1.1.0.2 haskeline-0.6.2.2
         haskell-src-1.0.1.3 mtl-1.1.0.2 old-time-1.0.0.2 pretty-1.0.1.0
         process-1.0.1.1 syb-0.1.0.1 utf8-string-0.3.6 xhtml-3000.2.0.1
         zlib-0.5.2.0
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/Agda-2.2.6/html/Agda.haddock
haddock-html: /usr/local/share/doc/Agda-2.2.6/html' | /usr/local/bin/ghc-pkg update -
